searchData={"items":[{"type":"behaviour","title":"ExTypesense","doc":"Public API functions to interact with Typesense.\n\nIf you want to implement field types for your Ecto schema,\nyou may need to encode the schema and add the callback `get_field_types/0`:\n\n```elixir\n# this example module can be found at: lib/ex_typesense/test_schema/person.ex\ndefmodule App.Person do\n  @behaviour ExTypesense\n\n  defimpl Jason.Encoder, for: __MODULE__ do\n    def encode(value, opts) do\n      value\n      |> Map.take([:id, :persons_id, :name, :age])\n      |> Enum.map(fn {key, val} ->\n        cond do\n          key === :id -> {key, to_string(Map.get(value, :id))}\n          key === :persons_id -> {key, Map.get(value, :id)}\n          true -> {key, val}\n        end\n      end)\n      |> Enum.into(%{})\n      |> Jason.Encode.map(opts)\n    end\n  end\n\n  schema \"persons\" do\n    field :name, :string\n    field :age, :integer\n    field :persons_id, :integer, virtual: true\n  end\n\n  @impl ExTypesense\n  def get_field_types do\n    primary_field = __MODULE__.__schema__(:source) <> \"_id\"\n\n    %{\n      default_sorting_field: primary_field,\n      fields:\n        [\n          %{name: primary_field, type: \"int32\"},\n          %{name: \"name\", type: \"string\"},\n          %{name: \"age\", type: \"integer\"}\n        ]\n    }\n  end\nend\n```","ref":"ExTypesense.html"},{"type":"function","title":"ExTypesense.api_stats/1","doc":"","ref":"ExTypesense.html#api_stats/1"},{"type":"function","title":"ExTypesense.cluster_metrics/1","doc":"","ref":"ExTypesense.html#cluster_metrics/1"},{"type":"function","title":"ExTypesense.create_collection/2","doc":"","ref":"ExTypesense.html#create_collection/2"},{"type":"function","title":"ExTypesense.create_document/2","doc":"","ref":"ExTypesense.html#create_document/2"},{"type":"function","title":"ExTypesense.delete_all_documents/2","doc":"","ref":"ExTypesense.html#delete_all_documents/2"},{"type":"function","title":"ExTypesense.delete_collection_alias/2","doc":"","ref":"ExTypesense.html#delete_collection_alias/2"},{"type":"function","title":"ExTypesense.delete_document/2","doc":"","ref":"ExTypesense.html#delete_document/2"},{"type":"function","title":"ExTypesense.delete_documents_by_query/2","doc":"","ref":"ExTypesense.html#delete_documents_by_query/2"},{"type":"function","title":"ExTypesense.drop_collection/2","doc":"","ref":"ExTypesense.html#drop_collection/2"},{"type":"function","title":"ExTypesense.get_collection/2","doc":"","ref":"ExTypesense.html#get_collection/2"},{"type":"function","title":"ExTypesense.get_collection_alias/2","doc":"","ref":"ExTypesense.html#get_collection_alias/2"},{"type":"function","title":"ExTypesense.get_collection_name/2","doc":"","ref":"ExTypesense.html#get_collection_name/2"},{"type":"function","title":"ExTypesense.get_document/3","doc":"","ref":"ExTypesense.html#get_document/3"},{"type":"callback","title":"ExTypesense.get_field_types/0","doc":"A callback function for creating the schema fields in Typesense.","ref":"ExTypesense.html#c:get_field_types/0"},{"type":"function","title":"ExTypesense.health/1","doc":"","ref":"ExTypesense.html#health/1"},{"type":"function","title":"ExTypesense.index_multiple_documents/2","doc":"","ref":"ExTypesense.html#index_multiple_documents/2"},{"type":"function","title":"ExTypesense.list_collection_aliases/1","doc":"","ref":"ExTypesense.html#list_collection_aliases/1"},{"type":"function","title":"ExTypesense.list_collections/1","doc":"","ref":"ExTypesense.html#list_collections/1"},{"type":"function","title":"ExTypesense.multi_search/2","doc":"","ref":"ExTypesense.html#multi_search/2"},{"type":"function","title":"ExTypesense.multi_search_ecto/2","doc":"","ref":"ExTypesense.html#multi_search_ecto/2"},{"type":"function","title":"ExTypesense.search/3","doc":"","ref":"ExTypesense.html#search/3"},{"type":"function","title":"ExTypesense.update_collection_fields/3","doc":"","ref":"ExTypesense.html#update_collection_fields/3"},{"type":"function","title":"ExTypesense.update_document/2","doc":"","ref":"ExTypesense.html#update_document/2"},{"type":"function","title":"ExTypesense.update_multiple_documents/2","doc":"","ref":"ExTypesense.html#update_multiple_documents/2"},{"type":"function","title":"ExTypesense.upsert_collection_alias/3","doc":"","ref":"ExTypesense.html#upsert_collection_alias/3"},{"type":"function","title":"ExTypesense.upsert_document/2","doc":"","ref":"ExTypesense.html#upsert_document/2"},{"type":"function","title":"ExTypesense.upsert_multiple_documents/2","doc":"","ref":"ExTypesense.html#upsert_multiple_documents/2"},{"type":"module","title":"ExTypesense.Cluster","doc":"Cluster specific operations.","ref":"ExTypesense.Cluster.html"},{"type":"function","title":"ExTypesense.Cluster.api_stats/1","doc":"Get stats about API endpoints.\n\nThis endpoint returns average requests per second and latencies for all requests in the last 10 seconds.","ref":"ExTypesense.Cluster.html#api_stats/1"},{"type":"function","title":"ExTypesense.Cluster.cluster_metrics/1","doc":"Get current RAM, CPU, Disk & Network usage metrics.","ref":"ExTypesense.Cluster.html#cluster_metrics/1"},{"type":"function","title":"ExTypesense.Cluster.health/1","doc":"Get health information about a Typesense node.","ref":"ExTypesense.Cluster.html#health/1"},{"type":"type","title":"ExTypesense.Cluster.response/0","doc":"","ref":"ExTypesense.Cluster.html#t:response/0"},{"type":"module","title":"ExTypesense.Collection","doc":"Module for creating, listing and deleting collections and aliases.\n\nIn Typesense, a [Collection](https://typesense.org/docs/latest/api/collections.html) is a group of related [Documents](https://typesense.org/docs/latest/api/documents.html) that is roughly equivalent to a table in a relational database. When we create a collection, we give it a name and describe the fields that will be indexed when a document is added to the collection.","ref":"ExTypesense.Collection.html"},{"type":"function","title":"ExTypesense.Collection.create_collection/2","doc":"Create collection from a map, or module name. Collection name is matched on table name if using Ecto schema by default.\n\nPlease refer to these [list of schema params](https://typesense.org/docs/latest/api/collections.html#schema-parameters).","ref":"ExTypesense.Collection.html#create_collection/2"},{"type":"function","title":"Examples - ExTypesense.Collection.create_collection/2","doc":"iex> schema = %{\n    ...>   name: \"companies\",\n    ...>   fields: [\n    ...>     %{name: \"company_name\", type: \"string\"},\n    ...>     %{name: \"companies_id\", type: \"int32\"},\n    ...>     %{name: \"country\", type: \"string\", facet: true}\n    ...>   ],\n    ...>   default_sorting_field: \"companies_id\"\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    %ExTypesense.Collection{\n      created_at: 1234567890,\n      default_sorting_field: \"companies_id\",\n      fields: [...],\n      name: \"companies\",\n      num_documents: 0,\n      symbols_to_index: [],\n      token_separators: []\n    }\n\n    iex> ExTypesense.create_collection(Person)\n    %ExTypesense.Collection{\n      created_at: 1234567890,\n      default_sorting_field: \"persons_id\",\n      fields: [...],\n      name: \"persons\",\n      num_documents: 0,\n      symbols_to_index: [],\n      token_separators: []\n    }","ref":"ExTypesense.Collection.html#create_collection/2-examples"},{"type":"function","title":"ExTypesense.Collection.delete_collection_alias/2","doc":"Deletes a collection alias. The collection itself\nis not affected by this action.","ref":"ExTypesense.Collection.html#delete_collection_alias/2"},{"type":"function","title":"ExTypesense.Collection.drop_collection/2","doc":"Permanently drops a collection by collection name or module name.\n\n**Note**: dropping a collection does not remove the referenced\nalias, only the indexed documents.","ref":"ExTypesense.Collection.html#drop_collection/2"},{"type":"function","title":"ExTypesense.Collection.get_collection/2","doc":"Get a specific collection by string or module name.","ref":"ExTypesense.Collection.html#get_collection/2"},{"type":"function","title":"ExTypesense.Collection.get_collection_alias/2","doc":"Get a specific collection alias by string or module name.","ref":"ExTypesense.Collection.html#get_collection_alias/2"},{"type":"function","title":"ExTypesense.Collection.get_collection_name/2","doc":"Get the collection name by alias.","ref":"ExTypesense.Collection.html#get_collection_name/2"},{"type":"function","title":"ExTypesense.Collection.list_collection_aliases/1","doc":"List all aliases and the corresponding collections that they map to.","ref":"ExTypesense.Collection.html#list_collection_aliases/1"},{"type":"function","title":"ExTypesense.Collection.list_collections/1","doc":"Lists all collections.","ref":"ExTypesense.Collection.html#list_collections/1"},{"type":"function","title":"ExTypesense.Collection.update_collection_fields/3","doc":"Make changes in a collection's fields: adding, removing\nor updating an existing field(s). Key name is `drop` to\nindicate which field is removed (example described below).\nOnly `fields` can only be updated at the moment.\n\n> **Note**: Typesense supports updating all fields\n> except the `id` field (since it's a special field\n> within Typesense).","ref":"ExTypesense.Collection.html#update_collection_fields/3"},{"type":"function","title":"Examples - ExTypesense.Collection.update_collection_fields/3","doc":"iex> fields = %{\n    ...>  fields: [\n    ...>    %{name: \"num_employees\", drop: true},\n    ...>    %{name: \"company_category\", type: \"string\"},\n    ...>  ],\n    ...> }\n    iex> ExTypesense.update_collection_fields(\"companies\", fields)\n    %ExTypesense.Collection{\n      created_at: 1234567890,\n      name: companies,\n      default_sorting_field: \"companies_id\",\n      fields: [...],\n      num_documents: 0,\n      symbols_to_index: [],\n      token_separators: []\n    }","ref":"ExTypesense.Collection.html#update_collection_fields/3-examples"},{"type":"function","title":"ExTypesense.Collection.upsert_collection_alias/3","doc":"Upserts a collection alias.","ref":"ExTypesense.Collection.html#upsert_collection_alias/3"},{"type":"type","title":"ExTypesense.Collection.response/0","doc":"","ref":"ExTypesense.Collection.html#t:response/0"},{"type":"type","title":"ExTypesense.Collection.t/0","doc":"","ref":"ExTypesense.Collection.html#t:t/0"},{"type":"module","title":"ExTypesense.Collection.Field","doc":"","ref":"ExTypesense.Collection.Field.html"},{"type":"type","title":"ExTypesense.Collection.Field.field_type/0","doc":"","ref":"ExTypesense.Collection.Field.html#t:field_type/0"},{"type":"type","title":"ExTypesense.Collection.Field.t/0","doc":"","ref":"ExTypesense.Collection.Field.html#t:t/0"},{"type":"module","title":"ExTypesense.Connection","doc":"Fetches credentials either from application env or map.","ref":"ExTypesense.Connection.html"},{"type":"function","title":"ExTypesense.Connection.new/1","doc":"Setting new connection or using the default config.\n\n> #### On using this function {: .info}\n> Functions e.g. `ExTypesense.search` don't need to explicitly pass this\n> unless you want to use another connection. See `README` for more details.\n> Also, `api_key` is hidden when invoking this function.","ref":"ExTypesense.Connection.html#new/1"},{"type":"function","title":"Examples - ExTypesense.Connection.new/1","doc":"iex> conn = ExTypesense.Connection.new()\n    %ExTypesense.Connection{\n      host: \"localhost\",\n      port: 8108,\n      scheme: \"http\",\n      ...\n    }","ref":"ExTypesense.Connection.html#new/1-examples"},{"type":"type","title":"ExTypesense.Connection.t/0","doc":"","ref":"ExTypesense.Connection.html#t:t/0"},{"type":"module","title":"ExTypesense.Document","doc":"Module for CRUD operations for documents. Refer to this [doc guide](https://typesense.org/docs/latest/api/documents.html).","ref":"ExTypesense.Document.html"},{"type":"function","title":"ExTypesense.Document.create_document/2","doc":"Indexes a single document using struct or map. When using struct,\nthe pk maps to document's id as string.\n\n**Note**: when using maps as documents, you should pass a key named \"collection_name\".","ref":"ExTypesense.Document.html#create_document/2"},{"type":"function","title":"Examples - ExTypesense.Document.create_document/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    iex> post =\n    ...>  %{\n    ...>    id: \"34\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 34,\n    ...>    title: \"the quick brown fox\",\n    ...>    description: \"jumps over the lazy dog\"\n    ...>  }\n    iex> ExTypesense.create_document(post)\n    {:ok,\n      %{\n        \"id\" => \"34\",\n        \"collection_name\" => \"posts\",\n        \"posts_id\" => 34,\n        \"title\" => \"the quick brown fox\",\n        \"description\" => \"jumps over the lazy dog\"\n      }\n    }","ref":"ExTypesense.Document.html#create_document/2-examples"},{"type":"function","title":"ExTypesense.Document.delete_all_documents/2","doc":"Deletes all documents in a collection.\n\n> #### On using this function {: .info}\n> As of this writing (v0.5.0), there's no built-in way of deleting\n> all documents via [Typesense docs](https://github.com/typesense/typesense/issues/1613#issuecomment-1994986258).\n> This function uses `delete_by_query` under the hood.","ref":"ExTypesense.Document.html#delete_all_documents/2"},{"type":"function","title":"ExTypesense.Document.delete_document/2","doc":"Deletes a document by id or struct.\n\n> #### Deleting a document by id {: .info}\n>\n> If you are deleting by id, pass it as a tuple (`{\"collection_name\", 23}`)","ref":"ExTypesense.Document.html#delete_document/2"},{"type":"function","title":"Examples - ExTypesense.Document.delete_document/2","doc":"iex> ExTypesense.create_collection(Post)\n    iex> post = Post |> limit(1) |> Repo.one()\n    iex> ExTypesense.create_collection(post)\n    iex> ExTypesense.delete_document(post)\n    {:ok,\n      %{\n        \"id\" => \"1\",\n        \"posts_id\" => 1,\n        \"title\" => \"our first post\",\n        \"collection_name\" => \"posts\"\n      }\n    }\n\n    iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    ...> ExTypesense.create_collection(schema)\n    iex> post =\n    ...>  %{\n    ...>    id: \"12\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 22,\n    ...>    title: \"the quick brown fox\"\n    ...>  }\n    iex> ExTypesense.create_document(post)\n    iex> ExTypesense.delete_document({\"posts\", 12})\n    {:ok,\n      %{\n        \"id\" => \"12\",\n        \"posts_id\" => 22,\n        \"title\" => \"the quick brown fox\",\n        \"collection_name\" => \"posts\"\n      }\n    }","ref":"ExTypesense.Document.html#delete_document/2-examples"},{"type":"function","title":"ExTypesense.Document.delete_documents_by_query/3","doc":"Deletes documents in a collection by query.\n\n> #### [Filter and batch size](https://typesense.org/docs/latest/api/documents.html#delete-by-query) {: .info}\n>\n> To delete all documents in a collection, you can use a filter that\n> matches all documents in your collection. For eg, if you have an\n> int32 field called popularity in your documents, you can use\n> `filter_by: \"popularity:>0\"` to delete all documents. Or if you have a\n> bool field called `in_stock` in your documents, you can use\n> `filter_by: \"in_stock:[true,false]\"` to delete all documents.\n>\n> Use the `batch_size` to control the number of documents that should\n> deleted at a time. A larger value will speed up deletions, but will\n> impact performance of other operations running on the server.\n>\n> Filter parameters can be found here: https://typesense.org/docs/latest/api/search.html#filter-parameters","ref":"ExTypesense.Document.html#delete_documents_by_query/3"},{"type":"function","title":"Examples - ExTypesense.Document.delete_documents_by_query/3","doc":"iex> query = %{\n    ...>   filter_by: \"num_employees:>100\",\n    ...>   batch_size: 100\n    ...> }\n    iex> ExTypesense.delete_documents_by_query(Employee, query)\n    {:ok, %{}}","ref":"ExTypesense.Document.html#delete_documents_by_query/3-examples"},{"type":"function","title":"ExTypesense.Document.get_document/3","doc":"Get a document from a collection.","ref":"ExTypesense.Document.html#get_document/3"},{"type":"function","title":"Examples - ExTypesense.Document.get_document/3","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    ...> ExTypesense.create_collection(schema)\n    ...> post = %{\n    ...>    id: \"444\",\n    ...>    collection_name: \"posts\",\n    ...>    title: \"the quick brown fox\"\n    ...> }\n    iex> ExTypesense.create_document(post)\n    iex> ExTypesense.get_document(\"posts\", 444)\n    {:ok,\n      %{\n        \"id\" => \"444\",\n        \"collection_name\" => \"posts\",\n        \"title\" => \"the quick brown fox\",\n      }\n    }","ref":"ExTypesense.Document.html#get_document/3-examples"},{"type":"function","title":"ExTypesense.Document.index_multiple_documents/2","doc":"Indexes multiple documents via maps.\n\n**Note**: when using maps as documents, you should pass a key named `collection_name`\nand with the lists of documents named `documents` (example shown below).","ref":"ExTypesense.Document.html#index_multiple_documents/2"},{"type":"function","title":"Examples - ExTypesense.Document.index_multiple_documents/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    ...> ExTypesense.create_collection(schema)\n    ...> posts = %{\n    ...>   collection_name: \"posts\",\n    ...>   documents: [\n    ...>     %{title: \"the quick brown fox\"},\n    ...>     %{title: \"jumps over the lazy dog\"}\n    ...>   ]\n    ...> }\n    iex> ExTypesense.index_multiple_documents(posts)\n    {:ok, [%{\"success\" => true}, %{\"success\" => true}]}","ref":"ExTypesense.Document.html#index_multiple_documents/2-examples"},{"type":"function","title":"ExTypesense.Document.update_document/2","doc":"Updates a single document using struct or map.\n\n**Note**: when using maps as documents, you should pass a key named \"collection_name\".","ref":"ExTypesense.Document.html#update_document/2"},{"type":"function","title":"Examples - ExTypesense.Document.update_document/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    iex> post =\n    ...>  %{\n    ...>    id: \"94\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 94,\n    ...>    title: \"the quick brown fox\"\n    ...>  }\n    iex> ExTypesense.create_document(post)\n    iex> updated_post =\n    ...>  %{\n    ...>    id: \"94\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 94,\n    ...>    title: \"test\"\n    ...>  }\n    iex> ExTypesense.update_document(updated_post)\n    {:ok,\n      %{\n        \"id\" => \"94\",\n        \"collection_name\" => \"posts\",\n        \"posts_id\" => 94,\n        \"title\" => \"sample post\"\n      }\n    }","ref":"ExTypesense.Document.html#update_document/2-examples"},{"type":"function","title":"ExTypesense.Document.update_multiple_documents/2","doc":"Updates multiple documents via maps.\n\n**Note**: when using maps as documents, you should pass a key named `collection_name`\nand with the lists of documents named `documents` (example shown below). Also add the `id`\nfor each documents.","ref":"ExTypesense.Document.html#update_multiple_documents/2"},{"type":"function","title":"Examples - ExTypesense.Document.update_multiple_documents/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    iex> posts = %{\n    ...>   collection_name: \"posts\",\n    ...>   documents: [\n    ...>     %{id: \"5\", title: \"the quick brown fox\"},\n    ...>     %{id: \"6\", title: \"jumps over the lazy dog\"}\n    ...>   ]\n    ...> }\n    iex> {:ok, _} = ExTypesense.index_multiple_documents(posts)\n    iex> updated_posts = %{\n    ...>   collection_name: \"posts\",\n    ...>   documents: [\n    ...>     %{id: \"5\", title: \"the quick\"},\n    ...>     %{id: \"6\", title: \"jumps over\"}\n    ...>   ]\n    ...> }\n    iex> ExTypesense.update_multiple_documents(updated_posts)\n    {:ok, [%{\"success\" => true}, %{\"success\" => true}]}","ref":"ExTypesense.Document.html#update_multiple_documents/2-examples"},{"type":"function","title":"ExTypesense.Document.upsert_document/2","doc":"Upserts a single document using struct or map.\n\n**Note**: when using maps as documents, you should pass a key named \"collection_name\".","ref":"ExTypesense.Document.html#upsert_document/2"},{"type":"function","title":"ExTypesense.Document.upsert_multiple_documents/2","doc":"Upserts multiple documents via maps. Same with `update_multiple_documents/1` with some\ndifference: creates one if not existed, otherwise updates it.\n\n**Note**: when using maps as documents, you should pass a key named `collection_name`\nand with the lists of documents named `documents` (example shown below). When `id` is added,\nit will update, otherwise creates a new document.\nfor each documents.","ref":"ExTypesense.Document.html#upsert_multiple_documents/2"},{"type":"function","title":"Examples - ExTypesense.Document.upsert_multiple_documents/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    iex> posts = %{\n    ...>   collection_name: \"posts\",\n    ...>   documents: [\n    ...>     %{id: \"0\", title: \"the quick\"},\n    ...>     %{id: \"1\", title: \"jumps over\"}\n    ...>   ]\n    ...> }\n    iex> ExTypesense.upsert_multiple_documents(posts)\n    {:ok, [%{\"success\" => true}, %{\"success\" => true}]}","ref":"ExTypesense.Document.html#upsert_multiple_documents/2-examples"},{"type":"type","title":"ExTypesense.Document.response/0","doc":"","ref":"ExTypesense.Document.html#t:response/0"},{"type":"module","title":"ExTypesense.HttpClient","doc":"Http client for Typesense server.","ref":"ExTypesense.HttpClient.html"},{"type":"function","title":"ExTypesense.HttpClient.api_key/0","doc":"Returns the Typesense's API key\n\n> #### Warning {: .warning}\n>\n> Even if `api_key` is hidden in `Connection` struct, this\n> function will still return the key and accessible inside\n> shell (assuming bad actors [pun unintended `:/`] can get in as well).","ref":"ExTypesense.HttpClient.html#api_key/0"},{"type":"function","title":"ExTypesense.HttpClient.get_host/0","doc":"","ref":"ExTypesense.HttpClient.html#get_host/0"},{"type":"function","title":"ExTypesense.HttpClient.get_options/0","doc":"","ref":"ExTypesense.HttpClient.html#get_options/0"},{"type":"function","title":"ExTypesense.HttpClient.get_port/0","doc":"","ref":"ExTypesense.HttpClient.html#get_port/0"},{"type":"function","title":"ExTypesense.HttpClient.get_scheme/0","doc":"","ref":"ExTypesense.HttpClient.html#get_scheme/0"},{"type":"function","title":"ExTypesense.HttpClient.request/2","doc":"Command for making http requests.","ref":"ExTypesense.HttpClient.html#request/2"},{"type":"function","title":"Options - ExTypesense.HttpClient.request/2","doc":"- `:body` Payload for passing as request body (defaults to `nil`).\n- `:path` Request path.\n- `:method` Request method (e.g. `:get`, `:post`, `:put`, `:patch`, `:delete`). Defaults to `:get`.\n- `:query` Request query params (defaults to `%{}`).\n- `:content_type` `\"Content-Type\"` request header. Defaults to `\"application/json\"`.","ref":"ExTypesense.HttpClient.html#request/2-options"},{"type":"function","title":"Examples - ExTypesense.HttpClient.request/2","doc":"iex> connection = %ExTypesense.Connection{\n    ...>   host: \"localhost\",\n    ...>   api_key: \"some_api_key\",\n    ...>   port: \"8108\",\n    ...>   scheme: \"http\"\n    ...> }\n\n    iex> HttpClient.request(connection, %{method: :post, path: \"/collections\", body: ExTypesense.TestSchema.Person})\n    {:ok,\n      [%{\n        \"created_at\" => 123456789,\n        \"default_sorting_field\" => \"person_id\",\n        \"fields\" => [...],\n        \"name\" => \"persons\",\n        \"num_documents\" => 0,\n        \"symbols_to_index\" => [],\n        \"token_separators\" => []\n      }]\n    }","ref":"ExTypesense.HttpClient.html#request/2-examples"},{"type":"type","title":"ExTypesense.HttpClient.request_body/0","doc":"","ref":"ExTypesense.HttpClient.html#t:request_body/0"},{"type":"type","title":"ExTypesense.HttpClient.request_method/0","doc":"","ref":"ExTypesense.HttpClient.html#t:request_method/0"},{"type":"type","title":"ExTypesense.HttpClient.request_path/0","doc":"","ref":"ExTypesense.HttpClient.html#t:request_path/0"},{"type":"module","title":"ExTypesense.Search","doc":"Module for searching documents.","ref":"ExTypesense.Search.html"},{"type":"function","title":"ExTypesense.Search.multi_search/2","doc":"Perform [multiple/federated](https://typesense.org/docs/latest/api/federated-multi-search.html)\nsearches at once.\nSearch params can be found [here](https://typesense.org/docs/latest/api/search.html#search-parameters).\n\n> This is especially useful to avoid round-trip network latencies\n> incurred otherwise if each of these requests are sent in separate\n> HTTP requests.\n\n> You can also use this feature to do a federated search across\n> multiple collections in a single HTTP request. For eg: in an\n> ecommerce products dataset, you can show results from both a\n> \"products\" collection, and a \"brands\" collection to the user, by\n> searching them in parallel with a multi_search request.","ref":"ExTypesense.Search.html#multi_search/2"},{"type":"function","title":"Examples - ExTypesense.Search.multi_search/2","doc":"iex> searches = [\n    ...>   %{collection: \"companies\", q: \"Loca Cola\"},\n    ...>   %{collection: Company, q: \"Burgler King\"},\n    ...>   %{collection: Catalog, q: \"umbrella\"}\n    ...> ]\n    iex> ExTypesense.multi_search(searches)\n    {:ok,\n     [\n       %{\n         \"facet_counts\" => [],\n         \"found\" => 0,\n         \"hits\" => [],\n         \"out_of\" => 0,\n         \"page\" => 1,\n         \"request_params\" => %{\n           \"collection_name\" => \"companies\",\n           \"per_page\" => 10,\n           \"q\" => \"Loca Cola\"\n         },\n         \"search_cutoff\" => false,\n         \"search_time_ms\" => 5\n       },\n       %{\n         \"facet_counts\" => [],\n         \"found\" => 0,\n         \"hits\" => [],\n         \"out_of\" => 0,\n         \"page\" => 1,\n         \"request_params\" => %{\n           \"collection_name\" => \"companies\",\n           \"per_page\" => 10,\n           \"q\" => \"Burgler King\"\n         },\n         \"search_cutoff\" => false,\n         \"search_time_ms\" => 5\n       },\n       %{\n         \"facet_counts\" => [],\n         \"found\" => 0,\n         \"hits\" => [],\n         \"out_of\" => 0,\n         \"page\" => 1,\n         \"request_params\" => %{\n           \"collection_name\" => \"companies\",\n           \"per_page\" => 10,\n           \"q\" => \"umbrella\"\n         },\n         \"search_cutoff\" => false,\n         \"search_time_ms\" => 5\n       }\n     ]\n    }","ref":"ExTypesense.Search.html#multi_search/2-examples"},{"type":"function","title":"ExTypesense.Search.multi_search_ecto/2","doc":"","ref":"ExTypesense.Search.html#multi_search_ecto/2"},{"type":"function","title":"ExTypesense.Search.search/3","doc":"Search from a document or Ecto Schema.\nSearch params can be found [here](https://typesense.org/docs/latest/api/search.html#search-parameters).","ref":"ExTypesense.Search.html#search/3"},{"type":"function","title":"Examples - ExTypesense.Search.search/3","doc":"iex> params = %{q: \"umbrella\", query_by: \"title,description\"}\n    iex> ExTypesense.search(Catalog, params)\n    {:ok,\n     %{\n      \"facet_counts\" => [],\n      \"found\" => 0,\n      \"hits\" => [],\n      \"out_of\" => 0,\n      \"page\" => 1,\n      \"request_params\" => %{\n        \"collection_name\" => \"catalogs\",\n        \"per_page\" => 10,\n        \"q\" => \"umbrella\"\n      },\n      \"search_cutoff\" => false,\n      \"search_time_ms\" => 5\n     }\n    }\n\n    iex> params = %{q: \"umbrella\", query_by: \"title,description\"}\n    iex> ExTypesense.search(\"catalogs\", params)\n    {:ok,\n     %{\n      \"facet_counts\" => [],\n      \"found\" => 0,\n      \"hits\" => [],\n      \"out_of\" => 0,\n      \"page\" => 1,\n      \"request_params\" => %{\n        \"collection_name\" => \"catalogs\",\n        \"per_page\" => 10,\n        \"q\" => \"umbrella\"\n      },\n      \"search_cutoff\" => false,\n      \"search_time_ms\" => 5\n     }\n    }","ref":"ExTypesense.Search.html#search/3-examples"},{"type":"type","title":"ExTypesense.Search.response/0","doc":"","ref":"ExTypesense.Search.html#t:response/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"major.minor.patch (yyyy.mm.dd) - Changelog","doc":"","ref":"changelog.html#major-minor-patch-yyyy-mm-dd"},{"type":"extras","title":"0.7.3 (2024.11.11) - Changelog","doc":"","ref":"changelog.html#0-7-3-2024-11-11"},{"type":"extras","title":"Added - Changelog","doc":"- `{:error, String.t()}` type for `Search.search/3`","ref":"changelog.html#added"},{"type":"extras","title":"0.7.2 (2024.11.07) - Changelog","doc":"","ref":"changelog.html#0-7-2-2024-11-07"},{"type":"extras","title":"Changed - Changelog","doc":"- Use `v27.1` of [Typesense](https://typesense.org/docs/27.1/api) in CI and local development.","ref":"changelog.html#changed"},{"type":"extras","title":"0.7.1 (2024.09.10) - Changelog","doc":"","ref":"changelog.html#0-7-1-2024-09-10"},{"type":"extras","title":"Removed - Changelog","doc":"- `:castore` dependency not passing on CI test","ref":"changelog.html#removed"},{"type":"extras","title":"0.7.0 (2024.09.10) - Changelog","doc":"","ref":"changelog.html#0-7-0-2024-09-10"},{"type":"extras","title":"Changed - Changelog","doc":"* HTTP request construction in `ExTypesense.HttpClient` to include `options`.\n* Bumped dependencies","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* `options` in config `config/configx.exs`.\n* `get_options/0` function in `HttpClient` to fetch the `options` configuration.\n* tests for `get_options/0` in `ExTypesense.HttpClientTest`.","ref":"changelog.html#added"},{"type":"extras","title":"0.6.0 (2024.07.15) - Changelog","doc":"","ref":"changelog.html#0-6-0-2024-07-15"},{"type":"extras","title":"Changed - Changelog","doc":"* Move application env variables from `test_helper.exs` to `config` directory, in usage for both `dev` and `test` environments.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* Function: [multi search](https://typesense.org/docs/26.0/api/federated-multi-search.html)","ref":"changelog.html#added"},{"type":"extras","title":"0.5.0 (2024.07.13) - Changelog","doc":"","ref":"changelog.html#0-5-0-2024-07-13"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` regarding `default_sorting_field`, where it joins the table name with `_id` (e.g. `images` is `images_id` instead of `image_id`).","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* Function: [delete by query](https://typesense.org/docs/26.0/api/documents.html#delete-by-query).\n* Function: [delete all documents](https://github.com/typesense/typesense/issues/1613#issuecomment-1994986258) in a collection.\n* Collection's schema [field parameters](https://typesense.org/docs/26.0/api/collections.html#field-parameters):\n  - `:vec_dist`\n  - `:store`\n  - `:reference`\n  - `:range_index`\n  - `:stem`","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Changelog","doc":"- `HttpClient.run` and `HttpClient.httpc_run` function (use `HttpClient.request`).","ref":"changelog.html#removed"},{"type":"extras","title":"0.4.3 (2024.07.03) - Changelog","doc":"","ref":"changelog.html#0-4-3-2024-07-03"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` regarding test and connection strings.\n* Replacing connection struct to map.","ref":"changelog.html#changed"},{"type":"extras","title":"0.4.2 (2024.06.19) - Changelog","doc":"","ref":"changelog.html#0-4-2-2024-06-19"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` and cheatsheet details regarding on setup for creation of collection schema.","ref":"changelog.html#changed"},{"type":"extras","title":"0.4.1 (2024.06.11) - Changelog","doc":"","ref":"changelog.html#0-4-1-2024-06-11"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` on running `docker compose`.","ref":"changelog.html#changed"},{"type":"extras","title":"0.4.0 (2024.05.20) - Changelog","doc":"","ref":"changelog.html#0-4-0-2024-05-20"},{"type":"extras","title":"Added - Changelog","doc":"* Connection module for dynamic loading of credentials.\n* Default connection config when running commands (e.g. create collections, etc.).","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"* Refactor `ExTypesense.HttpClient` on how to handle request.\n* Bumped dependencies' version.\n* Dropped usage of `:httpc` in favor of using [`Req library`](https://hex.pm/packages/req).","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"* Some functions from `Document` and `HttpClient` where soft depcrated in order to incorporate the `Connection` module for dynamic connections loaded from Ecto schema. If you read the docs, you might notice it's marked with `deprecated` and encourages to use the newer ones.","ref":"changelog.html#deprecated"},{"type":"extras","title":"0.3.5 (2023.08.13) - Changelog","doc":"","ref":"changelog.html#0-3-5-2023-08-13"},{"type":"extras","title":"Fixed - Changelog","doc":"* Fixed typos","ref":"changelog.html#fixed"},{"type":"extras","title":"0.3.4 (2023.07.12) - Changelog","doc":"","ref":"changelog.html#0-3-4-2023-07-12"},{"type":"extras","title":"Changed - Changelog","doc":"* Remove string conversion on struct id when deleting a document.","ref":"changelog.html#changed"},{"type":"extras","title":"0.3.3 (2023.07.11) - Changelog","doc":"","ref":"changelog.html#0-3-3-2023-07-11"},{"type":"extras","title":"Added - Changelog","doc":"* Add index_multiple_documents/1 clause for accepting struct args.","ref":"changelog.html#added"},{"type":"extras","title":"0.3.2 (2023.07.11) - Changelog","doc":"","ref":"changelog.html#0-3-2-2023-07-11"},{"type":"extras","title":"Changed - Changelog","doc":"* Maps struct pk to document's id.\n* Update http request timeout to `3,600` seconds.","ref":"changelog.html#changed"},{"type":"extras","title":"0.3.1 (2023.07.11) - Changelog","doc":"","ref":"changelog.html#0-3-1-2023-07-11"},{"type":"extras","title":"Changed - Changelog","doc":"* Increase connection timeout.","ref":"changelog.html#changed"},{"type":"extras","title":"0.3.0 (2023.06.20) - Changelog","doc":"","ref":"changelog.html#0-3-0-2023-06-20"},{"type":"extras","title":"Fixed - Changelog","doc":"* Fixed url request path for aliases.","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"* Refactor functions inside collection and document.\n* Changed return values from `{:ok, t()}` to `t()` only.\n* Parse schema field types for `float`, `boolean`, `string`, `integer` and a list with these corresponding types.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* Added cheatsheet section on docs.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.2 (2023.01.26) - Changelog","doc":"","ref":"changelog.html#0-2-2-2023-01-26"},{"type":"extras","title":"Changed - Changelog","doc":"* Updated docs","ref":"changelog.html#changed"},{"type":"extras","title":"0.2.1 (2023.01.22) - Changelog","doc":"","ref":"changelog.html#0-2-1-2023-01-22"},{"type":"extras","title":"Changed - Changelog","doc":"* Returned an ecto query instead of list of results.","ref":"changelog.html#changed"},{"type":"extras","title":"0.2.0 (2023.01.20) - Changelog","doc":"","ref":"changelog.html#0-2-0-2023-01-20"},{"type":"extras","title":"Added - Changelog","doc":"* Added search function which returns a list of structs or empty.","ref":"changelog.html#added"},{"type":"extras","title":"0.1.0 (2023.01.20) - Changelog","doc":"* Initial release","ref":"changelog.html#0-1-0-2023-01-20"},{"type":"extras","title":"Overview","doc":"# ExTypesense\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_typesense)](https://hex.pm/packages/ex_typesense)\n[![Hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ex_typesense)\n[![Actions Status](https://github.com/jaeyson/ex_typesense/actions/workflows/ci.yml/badge.svg)](https://github.com/jaeyson/ex_typesense/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_typesense)](https://hexdocs.pm/ex_typesense/license.html)\n[![Typesense badge](https://img.shields.io/badge/Typesense-v26.0-darkblue)](https://typesense.org/docs/26.0/api)\n[![Coverage Status](https://coveralls.io/repos/github/jaeyson/ex_typesense/badge.svg?branch=main)](https://coveralls.io/github/jaeyson/ex_typesense?branch=main)\n\nTypesense client for Elixir with support for your Ecto schemas.\n\n> **Note**: Breaking changes if you're upgrading from `0.3.x` to `0.5.x` version and above.","ref":"readme.html"},{"type":"extras","title":"Todo - Overview","doc":"- creating collection using auto schema detection\n- implement geosearch\n- implement curation\n- implement synonyms","ref":"readme.html#todo"},{"type":"extras","title":"Installation - Overview","doc":"ExTypesense requires Elixir `~> 1.14.x`. Read the [Changelog](CHANGELOG.md) for all available releases and requirements. This library is published to both [Hex.pm](https://hex.pm/ex_typesense) and [GitHub ](https://github.com/jaeyson/ex_typesense.git) repository.\n\nAdd `:ex_typesense` to your list of dependencies in the Elixir project config file, `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    # From default Hex package manager\n    {:ex_typesense, \"~> 0.7\"}\n\n    # Or from GitHub repository, if you want to latest greatest from main branch\n    {:ex_typesense, git: \"https://github.com/jaeyson/ex_typesense.git\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting started - Overview","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"0. Run local Typesense instance - Overview","doc":"```bash\ndocker compose up -d\n```\n\nMore info on spinning a local instance: https://typesense.org/docs/guide/install-typesense.html","ref":"readme.html#0-run-local-typesense-instance"},{"type":"extras","title":"1. Add credential to config - Overview","doc":"After you have setup a [local](./guides/running_local_typesense.md) Typesense or [Cloud hosted](https://cloud.typesense.org) instance, there are 2 ways to set the credentials:\n\n#### Option 1: Set credentials via config (e.g. `config/runtime.exs`)\n\nYou can set the following config details to the config file:\n\n```elixir\nif config_env() == :prod do # if you'll use this in prod environment\n  config :ex_typesense,\n    api_key: \"xyz\",\n    host: \"localhost\",\n    port: 8108,\n    scheme: \"http\",\n    options: %{}\n  ...\n```\n\n> **Note**: The `options` key can be used to pass additional configuration options such as custom Finch instance or receive timeout settings. You can add any options supported by Req here. For more details check [Req documentation](https://hexdocs.pm/req/Req.Steps.html#run_finch/1-request-options).\n\n> **Note**: If you use this for adding test in your app, you might want to add this in `config/test.exs`:\n\nFor Cloud hosted, you can generate and obtain the credentials from cluster instance admin interface:\n\n```elixir\nconfig :ex_typesense,\n  api_key: \"credential\", # Admin API key\n  host: \"111222333aaabbbcc-9.x9.typesense.net\", # Nodes\n  port: 443,\n  scheme: \"https\",\n  options: %{}\n```\n\n#### Option 2: Set credentials from a map\n\n> By default you don't need to pass connections every\n> time you use a function, if you use \"Option 1\" above.\n\nYou may have a `Connection` Ecto schema in your app and want to pass your own creds dynamically:\n\n```elixir\ndefmodule MyApp.Credential do\n  schema \"credentials\" do\n    field :node, :string\n    field :secret_key, :string\n    field :port, :integer\n  end\nend\n```\n\nAs long as the keys matches in `ExTypesense.Connection.t()`:\n\n```elixir\ncredential = MyApp.Credential |> where(id: ^8888) |> Repo.one()\n\nconn = %{\n  host: credential.node,\n  api_key: credential.secret_key,\n  port: credential.port,\n  scheme: \"https\"\n}\n\n# NOTE: create a collection and import documents\n# first before using the command below\nExTypesense.search(conn, collection_name, query)\n```\n\nOr convert your struct to map, as long as the keys matches in `ExTypesense.Connection.t()`:\n\n```elixir\nconn = Map.from_struct(MyApp.Credential)\n\n# NOTE: create a collection and import documents\n# first before using the command below\nExTypesense.search(conn, collection_name, query)\n```\n\nOr you don't want to change the fields in your Ecto schema, thus you convert it to map:\n\n```elixir\nconn = %Credential{\n  node: \"localhost\",\n  secret_key: \"xyz\",\n  port: 8108,\n  scheme: \"http\"\n}\n\nconn =\n  conn\n  |> Map.from_struct()\n  |> Map.drop([:node, :secret_key])\n  |> Map.put(:host, conn.node)\n  |> Map.put(:api_key, conn.secret_key)\n\n# NOTE: create a collection and import documents\n# first before using the command below\nExTypesense.search(conn, collection_name, query)\n```","ref":"readme.html#1-add-credential-to-config"},{"type":"extras","title":"2. Create a collection - Overview","doc":"There are 2 ways to create a collection, either via [Ecto schema](https://hexdocs.pm/ecto/Ecto.Schema.html) or using map ([an Elixir data type](https://hexdocs.pm/elixir/keywords-and-maps.html#maps-as-key-value-pairs)):\n\n#### Option 1: using Ecto\n\nIn this example, we're adding `persons_id` that points to the id of `persons` schema.\n\n> **Note**: we're using ` _id`. If you have table\n> e.g. named `persons`, it'll be `persons_id`.\n\n```elixir\ndefmodule Person do\n  use Ecto.Schema\n  @behaviour ExTypesense\n\n  defimpl Jason.Encoder, for: __MODULE__ do\n    def encode(value, opts) do\n      value\n      |> Map.take([:id, :persons_id, :name, :country])\n      |> Enum.map(fn {key, val} ->\n        cond do\n          key === :id -> {key, to_string(Map.get(value, :id))}\n          key === :persons_id -> {key, Map.get(value, :id)}\n          true -> {key, val}\n        end\n      end)\n      |> Enum.into(%{})\n      |> Jason.Encode.map(opts)\n    end\n  end\n\n  schema \"persons\" do\n    field(:name, :string)\n    field(:country, :string)\n    field(:persons_id, :integer, virtual: true)\n  end\n\n  @impl ExTypesense\n  def get_field_types do\n    primary_field = __MODULE__.__schema__(:source) <> \"_id\"\n\n    %{\n      # Or might as well just write persons_id instead. Up to you.\n      default_sorting_field: primary_field,\n      fields: [\n        %{name: primary_field, type: \"int32\"},\n        %{name: \"name\", type: \"string\"},\n        %{name: \"country\", type: \"string\"}\n      ]\n    }\n  end\nend\n```\n\nNext, create the collection from a module name.\n\n```elixir\nExTypesense.create_collection(Person)\n```\n\n#### Option 2: using map\n\n```elixir\nschema = %{\n  name: \"companies\",\n  fields: [\n    %{name: \"company_name\", type: \"string\"},\n    %{name: \"companies_id\", type: \"int32\"},\n    %{name: \"country\", type: \"string\"}\n  ],\n  default_sorting_field: \"companies_id\"\n}\n\nExTypesense.create_collection(schema)\n```","ref":"readme.html#2-create-a-collection"},{"type":"extras","title":"3. Indexing documents - Overview","doc":"For multiple documents:\n\n```elixir\nPost |> Repo.all() |> ExTypesense.index_multiple_documents()\n```\n\nFor single document:\n\n```elixir\nPost |> Repo.get!(123) |> ExTypesense.create_document()\n```","ref":"readme.html#3-indexing-documents"},{"type":"extras","title":"4. Search - Overview","doc":"```elixir\nparams = %{q: \"John Doe\", query_by: \"name\"}\n\nExTypesense.search(schema.name, params)\nExTypesense.search(Person, params)\n```\n\nCheck [Cheatsheet](https://hexdocs.pm/ex_typesense/cheatsheet.html) for more usage examples.","ref":"readme.html#4-search"},{"type":"extras","title":"Miscellaneous - Overview","doc":"","ref":"readme.html#miscellaneous"},{"type":"extras","title":"Use non-default Finch adapter - Overview","doc":"For instance, in a scenario where an application has multiple Finch pools configured for different services, a developer might want to specify a particular Finch pool for the `HttpClient` to use. This can be achieved by configuring the options as follows:\n\n```elixir\nconfig :ex_typesense,\n  api_key: \"XXXXXX\",\n  #...\n  options: [finch: MyApp.CustomFinch]\n```\n\nIn this example, `MyApp.CustomFinch` is a custom Finch pool that the developer has configured with specific connection options or other settings that differ from the default Finch pool.","ref":"readme.html#use-non-default-finch-adapter"},{"type":"extras","title":"License - Overview","doc":"Copyright (c) 2021 Jaeyson Anthony Y.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE","ref":"readme.html#license"},{"type":"extras","title":"Running local Typesense","doc":"# Running local Typesense\n\nThis document guides you through setting up a local Typesense instance for\ndevelopment purposes. Running a local instance allows you to experiment with\nsearch functionalities and integrate them into your development workflow\nseamlessly.","ref":"running_local_typesense.html"},{"type":"extras","title":"Prerequisites - Running local Typesense","doc":"Before we begin, ensure you have the following installed on your development\nmachine:\n\n- Docker:   - Docker provides a containerization platform\n  for running Typesense in an isolated environment.\n\n- Docker Compose:   - Docker Compose\n  helps manage multi-container applications like Typesense.\n\nOr use the [one line command](https://github.com/docker/docker-install) to install both:\n\n```bash\n# this is slightly edited so that you don't\n# have to save the file on the machine\ncurl -sSL https://get.docker.com/ | sh\n```","ref":"running_local_typesense.html#prerequisites"},{"type":"extras","title":"Setting up - Running local Typesense","doc":"We are using Docker compose to bootstrap a local Typesense instance from a\nsample docker compose file.\n\nClone the `ex_typesense` GitHub repository:\n\n```bash\ngit clone https://github.com/jaeyson/ex_typesense.git\n```\n\nNavigate to the cloned GitHub repository start the Typesense instance:\n\n```bash\ncd ex_typesense\n\ndocker compose up -d\n```\n\nMore info on spinning a local instance: https://typesense.org/docs/guide/install-typesense.html\n\nOnce you've started Typesense, you can verify its installation by accessing the\nhealth endpoint through a browser or `curl` in the terminal:\n\n```bash\n$ curl http://localhost:8108/health\n{\"ok\":true}\n```\n\nIn a separate terminal, you can view the logs of your local Typesense instance\nusing following command:\n\n```bash\n# logs from all instances\ndocker compose logs -f\n\n# or specifically Typesense\ndocker container logs --follow --tail 50 typesense\n```\n\nThis Docker Compose setup exposes three services with dedicated URLs:\n\n- http://localhost:8107 (Internal Server Status), provides information about the\n  health and status of your internal server.\n- http://localhost:8108 (Typesense Server and API), allows you to interact with\n  the Typesense search engine and its API functionalities.\n- http://localhost:8109 (Typesense Dashboard), opens the Typesense web interface\n  for managing your search collections and settings.","ref":"running_local_typesense.html#setting-up"},{"type":"extras","title":"Cheatsheet","doc":"# Cheatsheet Guide","ref":"cheatsheet.html"},{"type":"extras","title":"Collections - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#collections"},{"type":"extras","title":"Create using schema - Cheatsheet","doc":"```elixir\n# edit your Ecto schema\ndefmodule MyApp.Listings.Company do\n  use Ecto.Schema\n  @behaviour ExTypesense\n\n  defimpl Jason.Encoder, for: __MODULE__ do\n    def encode(value, opts) do\n      value\n      |> Map.take([:companies_id, :name, :country])\n      |> Enum.map(fn {key, val} ->\n        if key === :companies_id, do: {key, Map.get(value, :id)}, else: {key, val}\n      end)\n      |> Enum.into(%{})\n      |> Jason.Encode.map(opts)\n    end\n  end\n\n  schema \"companies\" do\n    field(:name, :string)\n    field(:country, :string)\n    field(:companies_id, :integer, virtual: true)\n  end\n\n  @impl ExTypesense\n  def get_field_types do\n    primary_field = __MODULE__.__schema__(:source) <> \"_id\"\n\n    %{\n      default_sorting_field: primary_field,\n      fields: [\n        %{name: primary_field, type: \"int32\"},\n        %{name: \"name\", type: \"string\"},\n        %{name: \"country\", type: \"string\"}\n      ]\n    }\n  end\nend\n\n# then try this on iex -S mix\niex> ExTypesense.create_collection(Company)\n{:ok,\n  %ExTypesense.Collection{\n    \"created_at\" => 1234567890,\n    \"default_sorting_field\" => \"companies_id\",\n    \"fields\" => [...],\n    \"name\" => \"companies\",\n    \"num_documents\" => 0,\n    \"symbols_to_index\" => [],\n    \"token_separators\" => []\n  }\n}\n```\n{: .wrap}","ref":"cheatsheet.html#create-using-schema"},{"type":"extras","title":"Create using map - Cheatsheet","doc":"```elixir\niex> schema =\n...> %{\n...>   name: \"companies\",\n...>   fields: [\n...>     %{name: \"company_name\", type: \"string\"},\n...>     %{name: \"companies_id\", type: \"int32\"},\n...>     %{name: \"country\", type: \"string\", facet: true}\n...>   ],\n...>   default_sorting_field: \"companies_id\"\n...> }\n\niex> ExTypesense.create_collection(schema)\n{:ok,\n  %ExTypesense.Collection{\n    \"created_at\" => 1234567890,\n    \"default_sorting_field\" => \"companies_id\",\n    \"fields\" => [...],\n    \"name\" => \"companies\",\n    \"num_documents\" => 0,\n    \"symbols_to_index\" => [],\n    \"token_separators\" => []\n  }\n}\n```\n{: .wrap}","ref":"cheatsheet.html#create-using-map"},{"type":"extras","title":"List collections - Cheatsheet","doc":"```elixir\niex> ExTypesense.list_collections()\n```\n{: .wrap}","ref":"cheatsheet.html#list-collections"},{"type":"extras","title":"Update a collection - Cheatsheet","doc":"```elixir\niex> schema =\n...> %{\n...>   fields: [\n...>     %{name: \"num_employees\", drop: true},\n...>     %{name: \"company_category\", type: \"string\"},\n...>   ],\n...> }\n\niex> ExTypesense.update_collection(\"companies\", schema)\n{:ok,\n  %ExTypesense.Collection{\n    \"created_at\" => nil,\n    \"name\" => nil,\n    \"default_sorting_field\" => \"companies_id\",\n    \"fields\" => [...],\n    \"num_documents\" => 0,\n    \"symbols_to_index\" => [],\n    \"token_separators\" => []\n  }\n}\n```\n{: .wrap}","ref":"cheatsheet.html#update-a-collection"},{"type":"extras","title":"Documents - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#documents"},{"type":"extras","title":"Index a document from an Ecto schema - Cheatsheet","doc":"```elixir\niex> post = Post |> limit(1) |> Repo.one()\n\niex> ExTypesense.create_document(post, :create)\n{:ok,\n  %{\n    \"id\" => \"12\",\n    \"posts_id\" => 12,\n    \"title\" => \"the quick brown fox\",\n    \"collection_name\" => \"posts\"\n  }\n}\n```","ref":"cheatsheet.html#index-a-document-from-an-ecto-schema"},{"type":"extras","title":"Update a document - Cheatsheet","doc":"```elixir\niex> post = Post |> limit(1) |> Repo.one()\n\niex> ExTypesense.update_document(post, 0)\n{:ok,\n  %{\n    \"id\" => \"0\",\n    \"collection_name\" => \"posts\",\n    \"posts_id\" => 34,\n    \"title\" => \"test\",\n    \"description\" => \"lorem ipsum\"\n  }\n}\n```","ref":"cheatsheet.html#update-a-document"},{"type":"extras","title":"Delete a document - Cheatsheet","doc":"```elixir\niex> ExTypesense.delete_document(Post, 0)\n{:ok,\n  %{\n    \"id\" => \"0\",\n    \"collection_name\" => \"posts\",\n    \"posts_id\" => 34,\n    \"title\" => \"test\",\n    \"description\" => \"lorem ipsum\"\n  }\n}\n```\n\n{: .wrap}","ref":"cheatsheet.html#delete-a-document"},{"type":"extras","title":"Delete a document by query - Cheatsheet","doc":"```elixir\niex> query = %{\n...>   filter_by: \"num_employees:>100\",\n...>   batch_size: 100\n...> }\niex> ExTypesense.delete_documents_by_query(Employee, query)\n{:ok, %{}}\n```","ref":"cheatsheet.html#delete-a-document-by-query"},{"type":"extras","title":"Indexes multiple documents - Cheatsheet","doc":"```elixir\niex> posts = Post |> Repo.all()\niex> ExTypesense.index_multiple_documents(posts, :post_id, :upsert)\n{:ok, [%{\"success\" => true}, %{\"success\" => true}]}\n```","ref":"cheatsheet.html#indexes-multiple-documents"},{"type":"extras","title":"How to use search - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#how-to-use-search"},{"type":"extras","title":"Search using Ecto schema (struct) - Cheatsheet","doc":"```elixir\niex> params = %{q: \"test\", query_by: \"title\"}\niex> ExTypesense.search(Post, params)\n{:ok,\n  %{\n    \"id\" => \"0\",\n    \"collection_name\" => \"posts\",\n    \"posts_id\" => 34,\n    \"title\" => \"test\",\n    \"description\" => \"lorem ipsum\"\n  }\n}\n```","ref":"cheatsheet.html#search-using-ecto-schema-struct"},{"type":"extras","title":"Multi search - Cheatsheet","doc":"```elixir\niex> searches = [\n...>   %{collection: \"companies\", q: \"Loca Cola\"},\n...>   %{collection: Company, q: \"Burgler King\"},\n...>   %{collection: Catalog, q: \"umbrella\"}\n...> ]\niex> ExTypesense.multi_search(searches)\n{:ok,\n  [\n    {\n      %{\"facet_counts\" => [], \"found\" => 0, \"hits\" => [], ...},\n      %{\"facet_counts\" => [], \"found\" => 0, \"hits\" => [], ...},\n      %{\"facet_counts\" => [], \"found\" => 0, \"hits\" => [], ...},\n    }\n  ]\n}\n```","ref":"cheatsheet.html#multi-search"},{"type":"extras","title":"Search using collection name (string) - Cheatsheet","doc":"```elixir\niex> params = %{q: \"test\", query_by: \"title\"}\niex> ExTypesense.search(\"posts\", params)\n{:ok,\n  %{\n    \"id\" => \"0\",\n    \"collection_name\" => \"posts\",\n    \"post_id\" => 34,\n    \"title\" => \"test\",\n    \"description\" => \"lorem ipsum\"\n  }\n}\n```","ref":"cheatsheet.html#search-using-collection-name-string"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2021 Jaeyson Anthony Y.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}